require 'rest-client'
require 'json'

class Probasketball::Api
  def initialize(api_key, options = {})
    @api_key = api_key
    @options = options
  end

  BASE_URLS = {
    :v1 => 'https://probasketballapi.com/',
    :v2 => 'http://api.probasketballapi.com/'
  }

  def post(url, params = {})
    response = RestClient.post build_url(url), build_params(params), headers
    Response::Success.new(JSON.parse(response), response.code)
  rescue RestClient::ExceptionWithResponse => e
    Response::Error.new(e.message)
  rescue JSON::ParserError => e
    Response::Error.new(response.body)
  end

  private

  def headers
    { accept: :json, content_type: :json }
  end

  def build_params(params)
    params.merge(api_key: api_key).to_json
  end

  def build_url(url)
    puts base_url + url
    base_url + url
  end

  def api_key
    @api_key
  end

  def version
    @options.fetch(:version, :v2)
  end

  def base_url
    BASE_URLS.fetch(version)
  end
end

require 'probasketball/api/response'
