module Probasketball::Collections
  class BaseCollection
    def initialize(api, url)
      @api = api
      @url = url
    end

    def fetchAll
      call!
    end

    def fetch(options = {})
      call!(options)
    end

    def find(options)
      !call(options).first
    end

    private

    def call!(options = {})
      response = @api.post(@url, options)
      return response.body if response.success?
      fail Probasketball::ApiError, response.body[:error]
    end
  end

  class MultipleBaseCollection
    def initialize(api, base_url)
      @api = api
      @base_url = base_url
    end

    def players
      @players ||= Players.new(@api, @base_url)
    end

    def teams
      @teams ||= Teams.new(@api, @base_url)
    end

    class Players < Probasketball::Collections::BaseCollection
      def initialize(api, base_url)
        super(api, base_url + 'player')
      end
    end

    class Teams < Probasketball::Collections::BaseCollection
      def initialize(api, base_url)
        super(api, base_url + 'team')
      end
    end
  end
end
